summaryrefslogtreecommitdiffstats
path: root/qt/qextscintilla.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'qt/qextscintilla.cpp')
-rw-r--r--qt/qextscintilla.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/qt/qextscintilla.cpp b/qt/qextscintilla.cpp
index 4b33791..d586e21 100644
--- a/qt/qextscintilla.cpp
+++ b/qt/qextscintilla.cpp
@@ -1036,7 +1036,7 @@ void QextScintilla::foldClick(int lineClick,int bstate)
{
if (bstate & ShiftButton)
{
// Ensure all tqchildren are visible.
SendScintilla(SCI_SETFOLDEXPANDED,lineClick,1);
foldExpand(lineClick,TRUE,TRUE,100,levelClick);
}
@@ -1044,13 +1044,13 @@ void QextScintilla::foldClick(int lineClick,int bstate)
{
if (SendScintilla(SCI_GETFOLDEXPANDED,lineClick))
{
// Contract this line and all its tqchildren.
SendScintilla(SCI_SETFOLDEXPANDED,lineClick,0L);
foldExpand(lineClick,FALSE,TRUE,0,levelClick);
}
else
{
// Expand this line and all its tqchildren.
SendScintilla(SCI_SETFOLDEXPANDED,lineClick,1);
foldExpand(lineClick,TRUE,TRUE,100,levelClick);
}
@@ -1119,7 +1119,7 @@ void QextScintilla::foldExpand(int &line,bool doExpand,bool force,
// Fully expand (if there is any line currently folded) all text. Otherwise,
// fold all text. This is mostly taken from SciTE.
-void QextScintilla::foldAll(bool tqchildren)
+void QextScintilla::foldAll(bool children)
{
recolor();
@@ -1142,7 +1142,7 @@ void QextScintilla::foldAll(bool tqchildren)
if (!(level & SC_FOLDLEVELHEADERFLAG))
continue;
- if (tqchildren ||
+ if (children ||
(SC_FOLDLEVELBASE == (level & SC_FOLDLEVELNUMBERMASK)))
{
if (expanding)
@@ -1036,7 +1036,7 @@ void QextScintilla::foldClick(int lineClick,int bstate)
if (bstate & ShiftButton)
{
- // Ensure all tqchildren are visible.
+ // Ensure all children are visible.
SendScintilla(SCI_SETFOLDEXPANDED,lineClick,1);
foldExpand(lineClick,TRUE,TRUE,100,levelClick);
@@ -1044,13 +1044,13 @@ void QextScintilla::foldClick(int lineClick,int bstate)
if (SendScintilla(SCI_GETFOLDEXPANDED,lineClick))
{
- // Contract this line and all its tqchildren.
+ // Contract this line and all its children.
SendScintilla(SCI_SETFOLDEXPANDED,lineClick,0L);
foldExpand(lineClick,FALSE,TRUE,0,levelClick);
@@ -1044,13 +1044,13 @@ void QextScintilla::foldClick(int lineClick,int bstate)
else
{
- // Expand this line and all its tqchildren.
+ // Expand this line and all its children.
SendScintilla(SCI_SETFOLDEXPANDED,lineClick,1);
foldExpand(lineClick,TRUE,TRUE,100,levelClick);